pub enum StructuralPatternError {
Show 17 variants
InvalidCell(CellError),
ReflectionLengthMismatch,
SiteLengthMismatch,
SpeciesLengthMismatch,
ScatteringOffsetLengthMismatch,
NonFiniteScatteringOffset,
UnsupportedScatteringOffset,
Scattering(ScatteringError),
Correction(IntegratedIntensityCorrectionError),
StructureFactor(StructureFactorBatchError),
Profile(ProfileError),
Contributions(CwContributionsError),
ReflectionOutsideAngularDomain,
InvalidInstrument(CwError),
InvalidPositionCorrection,
PatternWeightLengthMismatch,
NonFinitePatternWeight,
}Expand description
Invalid fused structural-pattern request.
Variants
InvalidCell(CellError)
The owned unit cell is invalid.
ReflectionLengthMismatch
Reflection indices and multiplicities have different lengths.
SiteLengthMismatch
Owned asymmetric-site arrays have different lengths.
SpeciesLengthMismatch
Scattering species count does not match the asymmetric-site count.
ScatteringOffsetLengthMismatch
Offset vectors are neither both empty nor matched to the asymmetric sites.
NonFiniteScatteringOffset
A fixed scattering offset is non-finite.
UnsupportedScatteringOffset
Fixed dispersion offsets were supplied to a non-X-ray model.
Scattering(ScatteringError)
Built-in scattering preparation or evaluation failed.
Correction(IntegratedIntensityCorrectionError)
Integrated-intensity correction evaluation failed.
StructureFactor(StructureFactorBatchError)
General-symmetry structural intensity failed.
Profile(ProfileError)
Grid validation failed.
Contributions(CwContributionsError)
CW/sample-physics accumulation failed.
ReflectionOutsideAngularDomain
A reflection is inaccessible for the monochromatic wavelength.
InvalidInstrument(CwError)
The CW instrument model is invalid.
InvalidPositionCorrection
A position-correction parameter is invalid.
PatternWeightLengthMismatch
Pattern reverse weights do not match the sample count.
NonFinitePatternWeight
A pattern reverse weight is non-finite.