calculate_structural_pattern_dense_with_context

Function calculate_structural_pattern_dense_with_context 

pub fn calculate_structural_pattern_dense_with_context(
    cell: UnitCell,
    space_group: &SpaceGroup,
    input: &StructuralPatternInputView<'_>,
    execution: &ExecutionContext,
) -> Result<StructuralPatternDenseResult, StructuralPatternError>
Calculate a dense structural linearization with a bounded context.

Errors

Returns an error for invalid inputs or allocation overflow.