StructuralPatternInputView

Struct StructuralPatternInputView 

pub struct StructuralPatternInputView<'a> {
Show 20 fields pub x_deg: &'a [f64], pub hkl: &'a [[i32; 3]], pub multiplicity: &'a [usize], pub fractional_xyz: &'a [[f64; 3]], pub occupancy: &'a [f64], pub u_iso_angstrom2: &'a [f64], pub anisotropic_mask: &'a [bool], pub u_aniso_cif_angstrom2: &'a [[f64; 6]], pub scattering_species: &'a [&'a str], pub scattering_real_offset: &'a [f64], pub scattering_imag_offset: &'a [f64], pub scale: f64, pub coordinate_tolerance: f64, pub instrument: ConstantWavelengthInstrument, pub axial_geometry: Option<FcjGeometry>, pub position_correction: MonochromaticPositionCorrection, pub correction_model: IntegratedIntensityCorrectionModel, pub scattering_model: BuiltInScatteringModel, pub contributions: CwContributionsView<'a>, pub support: SupportPolicy,
}
Borrowed structure, reflection, profile, and sample-physics inputs.

Fields

x_deg: &'a [f64]

Sorted pattern grid in degrees 2theta.

hkl: &'a [[i32; 3]]

Canonical Miller indices.

multiplicity: &'a [usize]

Powder multiplicity for each reflection.

fractional_xyz: &'a [[f64; 3]]

Asymmetric-unit fractional coordinates.

occupancy: &'a [f64]

Asymmetric-site occupancies.

u_iso_angstrom2: &'a [f64]

Asymmetric-site isotropic displacement in square ångströms.

anisotropic_mask: &'a [bool]

True for asymmetric sites described by fixed CIF U tensors.

u_aniso_cif_angstrom2: &'a [[f64; 6]]

CIF U tensors in component order 11,22,33,23,13,12.

scattering_species: &'a [&'a str]

Exact built-in table key for every asymmetric site.

scattering_real_offset: &'a [f64]

Fixed real X-ray dispersion offset for every site, or empty when absent.

scattering_imag_offset: &'a [f64]

Fixed imaginary X-ray dispersion offset for every site, or empty when absent.

scale: f64

Structural phase scale.

coordinate_tolerance: f64

Fixed symmetry-expansion deduplication tolerance.

instrument: ConstantWavelengthInstrument

Monochromatic CW instrument/profile parameters.

axial_geometry: Option<FcjGeometry>

Optional Finger–Cox–Jephcoat axial-divergence geometry.

position_correction: MonochromaticPositionCorrection

Explicit zero/sample-displacement position correction.

correction_model: IntegratedIntensityCorrectionModel

Explicit integrated-intensity correction model.

scattering_model: BuiltInScatteringModel

Built-in native scattering selection.

contributions: CwContributionsView<'a>

Vectorized sample-physics contribution batch.

support: SupportPolicy

Exact finite profile-support policy.