Module structural_tof

Module structural_tof 

Fused neutron structural time-of-flight pattern calculation.

Structs

StructuralTofDenseResult
Values and a parameter-major structural pattern Jacobian.
StructuralTofInputView
Borrowed neutron structural and bank inputs for one TOF pattern.
StructuralTofJvpResult
Values and one structural forward derivative product.
StructuralTofResult
Structural reflection values and fused TOF accumulation.
StructuralTofVjpResult
Values and one structural reverse derivative product.

Enums

StructuralTofError
Invalid fused structural TOF request.

Functions

calculate_structural_tof_pattern
Calculate one neutron structural TOF pattern.
calculate_structural_tof_pattern_dense
Calculate values and a dense structural TOF Jacobian.
calculate_structural_tof_pattern_dense_with_context
Calculate a dense structural TOF Jacobian with a bounded context.
calculate_structural_tof_pattern_jvp
Calculate values and one structural forward derivative product.
calculate_structural_tof_pattern_jvp_with_context
Calculate a structural forward product with a bounded context.
calculate_structural_tof_pattern_vjp
Calculate values and one structural reverse derivative product.
calculate_structural_tof_pattern_vjp_with_context
Calculate a structural reverse product with a bounded context.
calculate_structural_tof_pattern_with_context
Calculate values with an explicit bounded execution context.