Crate phasesmith_engine

Crate phasesmith_engine 

Native composition boundary for crystallography and powder profiles.

Structural pattern fusion is added in implementation unit 15. Re-exports keep PyO3 dependent on this facade rather than placing orchestration in the binding crate.

Re-exports

pub use structural_pattern::BuiltInScatteringModel;
pub use structural_pattern::MonochromaticPositionCorrection;
pub use structural_pattern::MonochromaticReflectionGeometry;
pub use structural_pattern::StructuralPatternDenseResult;
pub use structural_pattern::StructuralPatternError;
pub use structural_pattern::StructuralPatternInputView;
pub use structural_pattern::StructuralPatternJvpResult;
pub use structural_pattern::StructuralPatternResult;
pub use structural_pattern::StructuralPatternVjpResult;
pub use structural_pattern::calculate_monochromatic_reflection_geometry;
pub use structural_pattern::calculate_structural_pattern;
pub use structural_pattern::calculate_structural_pattern_dense;
pub use structural_pattern::calculate_structural_pattern_dense_with_context;
pub use structural_pattern::calculate_structural_pattern_jvp;
pub use structural_pattern::calculate_structural_pattern_jvp_with_context;
pub use structural_pattern::calculate_structural_pattern_vjp;
pub use structural_pattern::calculate_structural_pattern_vjp_with_context;
pub use structural_pattern::calculate_structural_pattern_with_context;
pub use phasesmith_core as profile;
pub use phasesmith_crystallography as crystallography;

Modules

structural_pattern
Fused built-in scattering, structural intensity, and CW profile composition.

Structs

PreparedStructuralModelInputView
Borrowed dynamic data for one phase model in a multiphase operation.
PreparedStructuralMultiphase
Reusable native scheduler for ordered structural phase models.
PreparedStructuralPatternInputView
Borrowed experiment and sample-physics data for evaluating a prepared phase.
PreparedStructuralPhase
Reusable, application-neutral structural phase with an owned worker budget.
PreparedStructuralSpectrum
Reusable native fixed-wavelength spectrum for one structural phase.
PreparedStructuralSpectrumInputView
Borrowed dynamic inputs for one prepared fixed-wavelength spectrum.
StructuralCalculationRequest
Owned application-boundary request for one multiphase structural calculation.
StructuralCalculationResult
Display-ready owned result from a structural calculation request.
StructuralModelInput
Owned sample-physics inputs for one prepared structural model.
StructuralMultiphaseResult
Ordered multiphase structural values and their combined profile.
StructuralPhaseDefinition
Owned crystallographic and scattering data for one structural phase.

Enums

PreparedStructuralModel
One native built-in structural model, monochromatic or fixed-spectrum.
StructuralMultiphaseError
Invalid native multiphase request.
StructuralSpectrumError
Invalid fixed-wavelength structural spectrum request.