Fused built-in scattering, structural intensity, and CW profile composition.
Structs
- Monochromatic
Position Correction - Monochromatic peak-position corrections evaluated with structural geometry.
- Monochromatic
Reflection Geometry - Reflection geometry needed by built-in sample-physics providers.
- Structural
Pattern Dense Result - Fused values and a reusable parameter-major structural pattern Jacobian.
- Structural
Pattern Input View - Borrowed structure, reflection, profile, and sample-physics inputs.
- Structural
Pattern JvpResult - Fused values and one structural forward derivative product.
- Structural
Pattern Result - Structural reflection intermediates and fused profile result.
- Structural
Pattern VjpResult - Fused values and one reverse product from pattern sample weights.
Enums
- Built
InScattering Model - Built-in native scattering model selected without a Python callback.
- Structural
Pattern Error - Invalid fused structural-pattern request.
Functions
- calculate_
monochromatic_ reflection_ geometry - Calculate corrected monochromatic reflection positions without profiles.
- calculate_
structural_ pattern - Calculate built-in scattering, structural intensities, and one CW profile.
- calculate_
structural_ pattern_ dense - Calculate values and a reusable dense structural pattern linearization.
- calculate_
structural_ pattern_ dense_ with_ context - Calculate a dense structural linearization with a bounded context.
- calculate_
structural_ pattern_ jvp - Calculate a full structural-pattern JVP without a dense pattern Jacobian.
- calculate_
structural_ pattern_ jvp_ with_ context - Calculate a structural JVP with a bounded execution context.
- calculate_
structural_ pattern_ vjp - Calculate a full structural-pattern transpose product from sample weights.
- calculate_
structural_ pattern_ vjp_ with_ context - Calculate a structural transpose product with a bounded context.
- calculate_
structural_ pattern_ with_ context - Calculate a structural pattern with an explicit bounded execution context.